DirectedGraph

Struct DirectedGraph 

pub struct DirectedGraph { /* private fields */ }
A directed graph.

Implementations

Source

impl DirectedGraph

pub fn new(order: usize) -> Self

Initialize an empty graph with order vertices.

pub fn add_edge(&mut self, v: usize, w: usize)

Add an edge from v to w.

pub fn delete_edge(&mut self, v: usize, w: usize)

Remove the edge from v to w.

pub fn has_edge(&self, v: usize, w: usize) -> bool

Check if there is an edge from v to w.

pub fn order(&self) -> usize

Return the number of vertices in the graph.

pub fn neighbors_of(&self, v: usize) -> &Vec<usize>

Return a reference to the adjacency list of vertex v.

pub fn size(&self) -> usize

Return the number of edges in the graph.

pub fn clear(&mut self)

Remove all edges from the graph.

pub fn outdegree(&self, v: usize) -> usize

Return the outdegree of vertex v.

pub fn indegree(&self, v: usize) -> usize

Return the indegree of vertex v.

Note: This requires O(|V| + |E|) time to compute.