pub struct EdgeAttributedDirectedGraph<Attr: Copy + Clone + Default> { /* private fields */ }Expand description
An edge-attributed directed graph.
Implementations
Sourceimpl<Attr: Copy + Clone + Default> EdgeAttributedDirectedGraph<Attr>
impl<Attr: Copy + Clone + Default> EdgeAttributedDirectedGraph<Attr>
Sourcepub fn add_edge(&mut self, v: usize, w: usize, attr: Attr)
pub fn add_edge(&mut self, v: usize, w: usize, attr: Attr)
Add an edge from vertex v to vertex w, with a specified attribute.
Sourcepub fn delete_edge(&mut self, v: usize, w: usize)
pub fn delete_edge(&mut self, v: usize, w: usize)
Remove the edge from vertex v to vertex w.
Sourcepub fn has_edge(&self, v: usize, w: usize) -> (bool, Attr)
pub fn has_edge(&self, v: usize, w: usize) -> (bool, Attr)
Check if there is an edge from vertex v to vertex w.
Sourcepub fn neighbors_of(&self, v: usize) -> &Vec<(usize, Attr)>
pub fn neighbors_of(&self, v: usize) -> &Vec<(usize, Attr)>
Return a reference to the adjacency list of vertex v.