pub struct EdgeAttributedUndirectedGraph<Attr: Copy + Clone + Default> { /* private fields */ }Expand description
An edge-attributed undirected graph.
Implementations
Sourceimpl<Attr: Copy + Clone + Default> EdgeAttributedUndirectedGraph<Attr>
impl<Attr: Copy + Clone + Default> EdgeAttributedUndirectedGraph<Attr>
Sourcepub fn add_edge(&mut self, v: usize, w: usize, attr: Attr)
pub fn add_edge(&mut self, v: usize, w: usize, attr: Attr)
Add an edge between vertices v and w, with a specified weight.
Sourcepub fn delete_edge(&mut self, v: usize, w: usize)
pub fn delete_edge(&mut self, v: usize, w: usize)
Remove the edge between vertices v and w.
Sourcepub fn has_edge(&self, v: usize, w: usize) -> (bool, Attr)
pub fn has_edge(&self, v: usize, w: usize) -> (bool, Attr)
Check if there is an edge between vertices v and w.
Sourcepub fn neighbors_of(&self, v: usize) -> &Vec<(usize, Attr)>
pub fn neighbors_of(&self, v: usize) -> &Vec<(usize, Attr)>
Return a reference to the adjacency list of vertex v.