pub struct UndirectedGraph { /* private fields */ }Expand description
An undirected graph.
Implementations
Sourceimpl UndirectedGraph
impl UndirectedGraph
Sourcepub fn delete_edge(&mut self, v: usize, w: usize)
pub fn delete_edge(&mut self, v: usize, w: usize)
Remove the edge between vertices v and w.
Sourcepub fn has_edge(&self, v: usize, w: usize) -> bool
pub fn has_edge(&self, v: usize, w: usize) -> bool
Check if there is an edge between vertices v and w.
Sourcepub fn neighbors_of(&self, v: usize) -> &Vec<usize>
pub fn neighbors_of(&self, v: usize) -> &Vec<usize>
Return a reference to the adjacency list of vertex v.